@@ -119,7 +119,7 @@ Application::Application(int& argc, char** argv):
                 initWatch();
             }
             delete lxqtSessionIface;
-            lxqtSessionIface = 0;
+            lxqtSessionIface = nullptr;
         }
     }
     else {
@@ -339,7 +339,7 @@ int Application::exec() {
     // So initially g_volume_monitor_get_volumes() returns nothing, but shortly after that
     // we get volume-added signals for all of the volumes. This is not what we want.
     // So, we wait for 3 seconds here to let it finish device discovery.
-    QTimer::singleShot(3000, this, SLOT(initVolumeManager()));
+    QTimer::singleShot(3000, this, &Application::initVolumeManager);
 
     return QCoreApplication::exec();
 }
@@ -905,7 +905,7 @@ void Application::onScreenDestroyed(QObject* screenObj) {
             }
         }
         if(reloadNeeded) {
-            QTimer::singleShot(0, this, SLOT(reloadDesktopsAsNeeded()));
+            QTimer::singleShot(0, this, &Application::reloadDesktopsAsNeeded);
         }
     }
 }
@@ -961,7 +961,7 @@ void Application::installSigtermHandler() {
         action.sa_handler = sigtermHandler;
         ::sigemptyset(&action.sa_mask);
         action.sa_flags = SA_RESTART;
-        if(::sigaction(SIGTERM, &action, 0) != 0) {
+        if(::sigaction(SIGTERM, &action, nullptr) != 0) {
             qWarning("Couldn't install SIGTERM handler");
         }
     }
@@ -975,6 +975,15 @@ void Application::onSigtermNotified() {
         notifier->setEnabled(false);
         char c;
         ::read(sigterm_fd[1], &c, sizeof(c));
+        // close all windows cleanly; otherwise, we might get this warning:
+        // "QBasicTimer::start: QBasicTimer can only be used with threads started with QThread"
+        const auto windows = topLevelWidgets();
+        for(const auto& win : windows) {
+            if(win->inherits("PCManFM::MainWindow")) {
+                MainWindow* mainWindow = static_cast<MainWindow*>(win);
+                mainWindow->close();
+            }
+        }
         quit();
         notifier->setEnabled(true);
     }
