@@ -39,7 +39,7 @@ static int iconSizes[] = {96, 72, 64, 48, 36, 32, 24, 20};
 DesktopPreferencesDialog::DesktopPreferencesDialog(QWidget* parent, Qt::WindowFlags f):
   QDialog(parent, f),
   editDesktopFolderEnabled(false),
-  desktopFolderWidget(0),
+  desktopFolderWidget(nullptr),
   desktopFolder() {
 
 
@@ -134,8 +134,7 @@ DesktopPreferencesDialog::DesktopPreferencesDialog(QWidget* parent, Qt::WindowFl
   resize(sizeHint()); // show it compact
 }
 
-DesktopPreferencesDialog::~DesktopPreferencesDialog() {
-}
+DesktopPreferencesDialog::~DesktopPreferencesDialog() = default;
 
 void DesktopPreferencesDialog::setupDesktopFolderUi()
 {
