@@ -223,6 +223,7 @@ MainWindow::MainWindow(Fm::FilePath path):
     group->setExclusive(true);
     group->addAction(ui.actionByFileName);
     group->addAction(ui.actionByMTime);
+    group->addAction(ui.actionByCrTime);
     group->addAction(ui.actionByDTime);
     group->addAction(ui.actionByFileSize);
     group->addAction(ui.actionByFileType);
@@ -370,8 +371,7 @@ MainWindow::MainWindow(Fm::FilePath path):
     }
 }
 
-MainWindow::~MainWindow() {
-}
+MainWindow::~MainWindow() = default;
 
 // Activate a view frame appropriately and give a special style to the inactive one(s).
 // NOTE: This function is called only with the split mode.
@@ -668,12 +668,15 @@ int MainWindow::addTabWithPage(TabPage* page, ViewFrame* viewFrame, Fm::FilePath
 
     Settings& settings = static_cast<Application*>(qApp)->settings();
     if(settings.switchToNewTab()) {
-        viewFrame->getTabBar()->setCurrentIndex(index);
+        viewFrame->getTabBar()->setCurrentIndex(index); // also focuses the view
         if (isMinimized()) {
             setWindowState((windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
             show();
         }
     }
+    else if(TabPage* tabPage = currentPage()) {
+        tabPage->folderView()->childView()->setFocus();
+    }
     if(!settings.alwaysShowTabs()) {
         viewFrame->getTabBar()->setVisible(viewFrame->getTabBar()->count() > 1);
     }
@@ -878,6 +881,10 @@ void MainWindow::on_actionByMTime_triggered(bool /*checked*/) {
     currentPage()->sort(Fm::FolderModel::ColumnFileMTime, currentPage()->sortOrder());
 }
 
+void MainWindow::on_actionByCrTime_triggered(bool /*checked*/) {
+    currentPage()->sort(Fm::FolderModel::ColumnFileCrTime, currentPage()->sortOrder());
+}
+
 void MainWindow::on_actionByDTime_triggered(bool /*checked*/) {
     currentPage()->sort(Fm::FolderModel::ColumnFileDTime, currentPage()->sortOrder());
 }
@@ -1014,7 +1021,11 @@ void MainWindow::on_actionAddToBookmarks_triggered() {
             auto parent = cwd.parent();
             if(!parent.isValid() || parent == cwd) { // a root path
                 bookmarkName = QString::fromUtf8(cwd.displayName().get());
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+                auto parts = bookmarkName.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#else
                 auto parts = bookmarkName.split(QLatin1Char('/'), QString::SkipEmptyParts);
+#endif
                 if(!parts.isEmpty()) {
                     bookmarkName = parts.last();
                 }
@@ -1036,7 +1047,7 @@ void MainWindow::on_actionAbout_triggered() {
     // the about dialog
     class AboutDialog : public QDialog {
     public:
-        explicit AboutDialog(QWidget* parent = 0, Qt::WindowFlags f = Qt::WindowFlags()) : QDialog(parent, f) {
+        explicit AboutDialog(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags()) : QDialog(parent, f) {
             ui.setupUi(this);
             ui.version->setText(tr("Version: %1").arg(QStringLiteral(PCMANFM_QT_VERSION)));
         }
@@ -1050,7 +1061,7 @@ void MainWindow::on_actionAbout_triggered() {
 void MainWindow::on_actionHiddenShortcuts_triggered() {
     class HiddenShortcutsDialog : public QDialog {
     public:
-        explicit HiddenShortcutsDialog(QWidget* parent = 0, Qt::WindowFlags f = Qt::WindowFlags()) : QDialog(parent, f) {
+        explicit HiddenShortcutsDialog(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags()) : QDialog(parent, f) {
             ui.setupUi(this);
             ui.treeWidget->setRootIsDecorated(false);
             ui.treeWidget->header()->setSectionResizeMode(QHeaderView::Stretch);
@@ -1290,6 +1301,7 @@ void MainWindow::updateViewMenuForCurrentPage() {
         }
         sortActions[Fm::FolderModel::ColumnFileName] = ui.actionByFileName;
         sortActions[Fm::FolderModel::ColumnFileMTime] = ui.actionByMTime;
+        sortActions[Fm::FolderModel::ColumnFileCrTime] = ui.actionByCrTime;
         sortActions[Fm::FolderModel::ColumnFileDTime] = ui.actionByDTime;
         sortActions[Fm::FolderModel::ColumnFileSize] = ui.actionByFileSize;
         sortActions[Fm::FolderModel::ColumnFileType] = ui.actionByFileType;
@@ -1391,6 +1403,8 @@ void MainWindow::updateUIForCurrentPage(bool setFocus) {
         ui.actionGoBack->setEnabled(tabPage->canBackward());
         ui.actionGoForward->setEnabled(tabPage->canForward());
 
+        ui.actionOpenAsAdmin->setEnabled(tabPage->path() && tabPage->path().isNative());
+
         updateViewMenuForCurrentPage();
         updateStatusBarForCurrentPage();
     }
@@ -1398,9 +1412,11 @@ void MainWindow::updateUIForCurrentPage(bool setFocus) {
     // also update the enabled state of Edit actions
     updateEditSelectedActions();
     bool isWritable(false);
+    bool isNative(false);
     if(tabPage && tabPage->folder()) {
         if(auto info = tabPage->folder()->info()) {
             isWritable = info->isWritable();
+            isNative = info->isNative();
         }
     }
     ui.actionPaste->setEnabled(isWritable);
@@ -1408,6 +1424,7 @@ void MainWindow::updateUIForCurrentPage(bool setFocus) {
     // disable creation shortcuts too
     ui.actionNewFolder->setEnabled(isWritable);
     ui.actionNewBlankFile->setEnabled(isWritable);
+    ui.actionCreateLauncher->setEnabled(isWritable && isNative);
 }
 
 void MainWindow::onStackedWidgetWidgetRemoved(int index) {
@@ -1475,7 +1492,9 @@ void MainWindow::onTabPageTitleChanged() {
                 setWindowTitle(tabPage->title());
 
                 // Since TabPage::titleChanged is emitted on changing directory,
-                // the enabled state of Paste action should be updated here
+                // the enabled state of some actions should be updated here
+                bool isNative(tabPage->path() && tabPage->path().isNative());
+                ui.actionOpenAsAdmin->setEnabled(isNative);
                 bool isWritable(false);
                 if(tabPage && tabPage->folder()) {
                     if(auto info = tabPage->folder()->info()) {
@@ -1486,6 +1505,7 @@ void MainWindow::onTabPageTitleChanged() {
                 ui.menuCreateNew->setEnabled(isWritable);
                 ui.actionNewFolder->setEnabled(isWritable);
                 ui.actionNewBlankFile->setEnabled(isWritable);
+                ui.actionCreateLauncher->setEnabled(isWritable && isNative);
             }
         }
     }
@@ -1949,6 +1969,17 @@ void MainWindow::updateFromSettings(Settings& settings) {
     }
 }
 
+void MainWindow::on_actionOpenAsAdmin_triggered() {
+    if(TabPage* page = currentPage()) {
+        if(auto path = page->path()) {
+            if(path.isNative()) {
+                CStrPtr admin{g_strconcat("admin://", path.localPath().get(), nullptr)};
+                chdir(Fm::FilePath::fromPathStr(admin.get()));
+            }
+        }
+    }
+}
+
 void MainWindow::on_actionOpenAsRoot_triggered() {
     TabPage* page = currentPage();
 
@@ -1999,16 +2030,18 @@ void MainWindow::on_actionOpenAsRoot_triggered() {
 
 void MainWindow::on_actionFindFiles_triggered() {
     Application* app = static_cast<Application*>(qApp);
-    auto selectedPaths = currentPage()->selectedFilePaths();
+    const auto files = currentPage()->selectedFiles();
     QStringList paths;
-    if(!selectedPaths.empty()) {
-        for(auto& path: selectedPaths) {
+    if(!files.empty()) {
+        for(const auto& file: files) {
             // FIXME: is it ok to use display name here?
             // This might be broken on filesystems with non-UTF-8 filenames.
-            paths.append(QString::fromUtf8(path.displayName().get()));
+            if(file->isDir()) {
+                paths.append(QString::fromUtf8(file->path().displayName().get()));
+            }
         }
     }
-    else {
+    if(paths.isEmpty()) {
         paths.append(currentPage()->pathName());
     }
     app->findFiles(paths);
@@ -2022,6 +2055,13 @@ void MainWindow::on_actionOpenTerminal_triggered() {
     }
 }
 
+void MainWindow::on_actionCreateLauncher_triggered() {
+    TabPage* page = currentPage();
+    if(page) {
+        page->ceateShortcut();
+    }
+}
+
 void MainWindow::on_actionCopyFullPath_triggered() {
     TabPage* page = currentPage();
     if(page) {
