@@ -150,6 +150,7 @@ protected Q_SLOTS:
 
     void on_actionByFileName_triggered(bool checked);
     void on_actionByMTime_triggered(bool checked);
+    void on_actionByCrTime_triggered(bool checked);
     void on_actionByDTime_triggered(bool checked);
     void on_actionByOwner_triggered(bool checked);
     void on_actionByGroup_triggered(bool checked);
@@ -176,6 +177,8 @@ protected Q_SLOTS:
     void on_actionEditBookmarks_triggered();
 
     void on_actionOpenTerminal_triggered();
+    void on_actionCreateLauncher_triggered();
+    void on_actionOpenAsAdmin_triggered();
     void on_actionOpenAsRoot_triggered();
     void on_actionCopyFullPath_triggered();
     void on_actionFindFiles_triggered();
