@@ -49,9 +49,7 @@ PreferencesDialog::PreferencesDialog(QString activePage, QWidget* parent):
     adjustSize();
 }
 
-PreferencesDialog::~PreferencesDialog() {
-
-}
+PreferencesDialog::~PreferencesDialog() = default;
 
 static void findIconThemesInDir(QHash<QString, QString>& iconThemes, QString dirName) {
     QDir dir(dirName);
@@ -238,7 +236,12 @@ void PreferencesDialog::initBehaviorPage(Settings& settings) {
 void PreferencesDialog::initThumbnailPage(Settings& settings) {
     ui.showThumbnails->setChecked(settings.showThumbnails());
     ui.thumbnailLocal->setChecked(settings.thumbnailLocalFilesOnly());
-    ui.maxThumbnailFileSize->setValue(settings.maxThumbnailFileSize());
+
+    // the max. thumbnail size spinboxes are in MiB
+    double m = settings.maxThumbnailFileSize();
+    ui.maxThumbnailFileSize->setValue(qBound(0.0, m / 1024, 1024.0));
+    int m1 = settings.maxExternalThumbnailFileSize();
+    ui.maxExternalThumbnailFileSize->setValue(m1 < 0 ? -1 : qMin(m1 / 1024, 2048));
 }
 
 void PreferencesDialog::initVolumePage(Settings& settings) {
@@ -351,7 +354,10 @@ void PreferencesDialog::applyBehaviorPage(Settings& settings) {
 void PreferencesDialog::applyThumbnailPage(Settings& settings) {
     settings.setShowThumbnails(ui.showThumbnails->isChecked());
     settings.setThumbnailLocalFilesOnly(ui.thumbnailLocal->isChecked());
-    settings.setMaxThumbnailFileSize(ui.maxThumbnailFileSize->value());
+    // the max. thumbnail size spinboxes are in MiB
+    settings.setMaxThumbnailFileSize(qRound(ui.maxThumbnailFileSize->value() * 1024));
+    int m = ui.maxExternalThumbnailFileSize->value();
+    settings.setMaxExternalThumbnailFileSize(m < 0 ? -1 : m * 1024);
 }
 
 void PreferencesDialog::applyVolumePage(Settings& settings) {
