@@ -139,9 +139,7 @@ Settings::Settings():
     searchhHidden_(false) {
 }
 
-Settings::~Settings() {
-
-}
+Settings::~Settings() = default;
 
 QString Settings::xdgUserConfigDir() {
     QString dirName;
@@ -225,8 +223,6 @@ bool Settings::loadFile(QString filePath) {
     confirmTrash_ = settings.value(QStringLiteral("ConfirmTrash"), false).toBool();
     setQuickExec(settings.value(QStringLiteral("QuickExec"), false).toBool());
     selectNewFiles_ = settings.value(QStringLiteral("SelectNewFiles"), false).toBool();
-    // bool thumbnailLocal_;
-    // bool thumbnailMax;
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Desktop"));
@@ -274,6 +270,7 @@ bool Settings::loadFile(QString filePath) {
     settings.beginGroup(QStringLiteral("Thumbnail"));
     showThumbnails_ = settings.value(QStringLiteral("ShowThumbnails"), true).toBool();
     setMaxThumbnailFileSize(settings.value(QStringLiteral("MaxThumbnailFileSize"), 4096).toInt());
+    setMaxExternalThumbnailFileSize(settings.value(QStringLiteral("MaxExternalThumbnailFileSize"), -1).toInt());
     setThumbnailLocalFilesOnly(settings.value(QStringLiteral("ThumbnailLocalFilesOnly"), true).toBool());
     settings.endGroup();
 
@@ -308,7 +305,12 @@ bool Settings::loadFile(QString filePath) {
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Places"));
-    hiddenPlaces_ = settings.value(QStringLiteral("HiddenPlaces")).toStringList().toSet();
+    QStringList hiddenPlacesList = settings.value(QStringLiteral("HiddenPlaces")).toStringList();
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    hiddenPlaces_ = QSet<QString>(hiddenPlacesList.begin(), hiddenPlacesList.end());
+#else
+    hiddenPlaces_ = hiddenPlacesList.toSet();
+#endif
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Window"));
@@ -372,8 +374,6 @@ bool Settings::saveFile(QString filePath) {
     settings.setValue(QStringLiteral("ConfirmTrash"), confirmTrash_);
     settings.setValue(QStringLiteral("QuickExec"), quickExec_);
     settings.setValue(QStringLiteral("SelectNewFiles"), selectNewFiles_);
-    // bool thumbnailLocal_;
-    // bool thumbnailMax;
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Desktop"));
@@ -413,6 +413,7 @@ bool Settings::saveFile(QString filePath) {
     settings.beginGroup(QStringLiteral("Thumbnail"));
     settings.setValue(QStringLiteral("ShowThumbnails"), showThumbnails_);
     settings.setValue(QStringLiteral("MaxThumbnailFileSize"), maxThumbnailFileSize());
+    settings.setValue(QStringLiteral("MaxExternalThumbnailFileSize"), maxExternalThumbnailFileSize());
     settings.setValue(QStringLiteral("ThumbnailLocalFilesOnly"), thumbnailLocalFilesOnly());
     settings.endGroup();
 
@@ -447,8 +448,12 @@ bool Settings::saveFile(QString filePath) {
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Places"));
-    QStringList hiddenPlaces = hiddenPlaces_.toList();
-    settings.setValue(QStringLiteral("HiddenPlaces"), hiddenPlaces);
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    QStringList hiddenPlacesList(hiddenPlaces_.begin(), hiddenPlaces_.end());
+#else
+    QStringList hiddenPlacesList = hiddenPlaces_.values();
+#endif
+    settings.setValue(QStringLiteral("HiddenPlaces"), hiddenPlacesList);
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Window"));
@@ -607,6 +612,9 @@ static const char* sortColumnToString(Fm::FolderModel::ColumnId value) {
     case Fm::FolderModel::ColumnFileMTime:
         ret = "mtime";
         break;
+    case Fm::FolderModel::ColumnFileCrTime:
+        ret = "crtime";
+        break;
     case Fm::FolderModel::ColumnFileDTime:
         ret = "dtime";
         break;
@@ -634,6 +642,9 @@ static Fm::FolderModel::ColumnId sortColumnFromString(const QString str) {
     else if(str == QLatin1String("mtime")) {
         ret = Fm::FolderModel::ColumnFileMTime;
     }
+    else if(str == QLatin1String("crtime")) {
+        ret = Fm::FolderModel::ColumnFileCrTime;
+    }
     else if(str == QLatin1String("dtime")) {
         ret = Fm::FolderModel::ColumnFileDTime;
     }
