@@ -66,21 +66,24 @@ void TabBar::mouseMoveEvent(QMouseEvent *event)
 
         QPointer<QDrag> drag = new QDrag(this);
         QMimeData *mimeData = new QMimeData;
-        mimeData->setData("application/pcmanfm-qt-tab", QByteArray());
+        mimeData->setData(QStringLiteral("application/pcmanfm-qt-tab"), QByteArray());
         drag->setMimeData(mimeData);
-        Qt::DropAction dragged = drag->exec();
-        if(dragged == Qt::IgnoreAction) { // a tab is dropped outside all windows
-            if(count() > 1) {
+        int N = count();
+        Qt::DropAction dragged = drag->exec(Qt::MoveAction);
+        if(dragged != Qt::MoveAction) { // a tab is dropped outside all windows
+            if(N > 1) {
                 Q_EMIT tabDetached();
             }
             else {
                 finishMouseMoveEvent();
             }
-            event->accept();
         }
-        else if(dragged == Qt::MoveAction) { // a tab is dropped into another window
-            event->accept();
+        else { // a tab is dropped into another window
+            if(count() == N) {
+                releaseMouse(); // release the mouse if the drop isn't accepted
+            }
         }
+        event->accept();
         drag->deleteLater();
     }
     else {
@@ -110,7 +113,7 @@ void TabBar::mouseReleaseEvent(QMouseEvent *event) {
 
 // Let the main window receive dragged tabs!
 void TabBar::dragEnterEvent(QDragEnterEvent *event) {
-    if(detachable_ && event->mimeData()->hasFormat("application/pcmanfm-qt-tab")) {
+    if(detachable_ && event->mimeData()->hasFormat(QStringLiteral("application/pcmanfm-qt-tab"))) {
         event->ignore();
     }
 }
